# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: session_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14session_status.proto\x12\"armonik.api.grpc.v1.session_status*i\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x1a\n\x16SESSION_STATUS_RUNNING\x10\x01\x12\x1c\n\x18SESSION_STATUS_CANCELLED\x10\x02\x42\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'session_status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _SESSIONSTATUS._serialized_start=60
  _SESSIONSTATUS._serialized_end=165
# @@protoc_insertion_point(module_scope)
