# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: results_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import result_status_pb2 as result__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14results_common.proto\x12\x1b\x61rmonik.api.grpc.v1.results\x1a\x13result_status.proto\"\x99\x01\n\tResultRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x12\n\ncreated_at\x18\x05 \x01(\t\"\xc9\x06\n\x12ListResultsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x46\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x36.armonik.api.grpc.v1.results.ListResultsRequest.Filter\x12\x42\n\x04sort\x18\x04 \x01(\x0b\x32\x34.armonik.api.grpc.v1.results.ListResultsRequest.Sort\x1a\xb1\x01\n\x06\x46ilter\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x15\n\rcreated_after\x18\x05 \x01(\t\x12\x16\n\x0e\x63reated_before\x18\x06 \x01(\t\x1a\xa6\x01\n\x04Sort\x12K\n\x05\x66ield\x18\x01 \x01(\x0e\x32<.armonik.api.grpc.v1.results.ListResultsRequest.OrderByField\x12Q\n\tdirection\x18\x02 \x01(\x0e\x32>.armonik.api.grpc.v1.results.ListResultsRequest.OrderDirection\"\xc2\x01\n\x0cOrderByField\x12\x1e\n\x1aORDER_BY_FIELD_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORDER_BY_FIELD_SESSION_ID\x10\x01\x12\x17\n\x13ORDER_BY_FIELD_NAME\x10\x02\x12 \n\x1cORDER_BY_FIELD_OWNER_TASK_ID\x10\x03\x12\x19\n\x15ORDER_BY_FIELD_STATUS\x10\x04\x12\x1d\n\x19ORDER_BY_FIELD_CREATED_AT\x10\x05\"d\n\x0eOrderDirection\x12\x1f\n\x1bORDER_DIRECTION_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDER_DIRECTION_ASC\x10\x01\x12\x18\n\x14ORDER_DIRECTION_DESC\x10\x02\"~\n\x13ListResultsResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\">\n\x15GetOwnerTaskIdRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\t\"\xb9\x01\n\x16GetOwnerTaskIdResponse\x12V\n\x0bresult_task\x18\x01 \x03(\x0b\x32\x41.armonik.api.grpc.v1.results.GetOwnerTaskIdResponse.MapResultTask\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a\x33\n\rMapResultTask\x12\x11\n\tresult_id\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\tB\x1e\xaa\x02\x1b\x41rmoniK.Api.gRPC.V1.Resultsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'results_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\033ArmoniK.Api.gRPC.V1.Results'
  _RESULTRAW._serialized_start=75
  _RESULTRAW._serialized_end=228
  _LISTRESULTSREQUEST._serialized_start=231
  _LISTRESULTSREQUEST._serialized_end=1072
  _LISTRESULTSREQUEST_FILTER._serialized_start=427
  _LISTRESULTSREQUEST_FILTER._serialized_end=604
  _LISTRESULTSREQUEST_SORT._serialized_start=607
  _LISTRESULTSREQUEST_SORT._serialized_end=773
  _LISTRESULTSREQUEST_ORDERBYFIELD._serialized_start=776
  _LISTRESULTSREQUEST_ORDERBYFIELD._serialized_end=970
  _LISTRESULTSREQUEST_ORDERDIRECTION._serialized_start=972
  _LISTRESULTSREQUEST_ORDERDIRECTION._serialized_end=1072
  _LISTRESULTSRESPONSE._serialized_start=1074
  _LISTRESULTSRESPONSE._serialized_end=1200
  _GETOWNERTASKIDREQUEST._serialized_start=1202
  _GETOWNERTASKIDREQUEST._serialized_end=1264
  _GETOWNERTASKIDRESPONSE._serialized_start=1267
  _GETOWNERTASKIDRESPONSE._serialized_end=1452
  _GETOWNERTASKIDRESPONSE_MAPRESULTTASK._serialized_start=1401
  _GETOWNERTASKIDRESPONSE_MAPRESULTTASK._serialized_end=1452
# @@protoc_insertion_point(module_scope)
