# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import session_status_pb2 as session__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15sessions_common.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x14session_status.proto\"\x8f\x02\n\nSessionRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x12\x15\n\rpartition_ids\x18\x03 \x03(\t\x12\x31\n\x07options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc9\x01\n\x0eSessionSummary\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xef\x07\n\x13ListSessionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12H\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x38.armonik.api.grpc.v1.sessions.ListSessionsRequest.Filter\x12\x44\n\x04sort\x18\x04 \x01(\x0b\x32\x36.armonik.api.grpc.v1.sessions.ListSessionsRequest.Sort\x1a\xe8\x02\n\x06\x46ilter\x12\x18\n\x10\x61pplication_name\x18\x01 \x01(\t\x12\x1b\n\x13\x61pplication_version\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x31\n\rcreated_after\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x63reated_before\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63\x61ncelled_after\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10\x63\x61ncelled_before\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06status\x18\x08 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x1a\xaa\x01\n\x04Sort\x12M\n\x05\x66ield\x18\x01 \x01(\x0e\x32>.armonik.api.grpc.v1.sessions.ListSessionsRequest.OrderByField\x12S\n\tdirection\x18\x02 \x01(\x0e\x32@.armonik.api.grpc.v1.sessions.ListSessionsRequest.OrderDirection\"\xa8\x01\n\x0cOrderByField\x12\x1e\n\x1aORDER_BY_FIELD_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORDER_BY_FIELD_SESSION_ID\x10\x01\x12\x19\n\x15ORDER_BY_FIELD_STATUS\x10\x02\x12\x1d\n\x19ORDER_BY_FIELD_CREATED_AT\x10\x03\x12\x1f\n\x1bORDER_BY_FIELD_CANCELLED_AT\x10\x04\"d\n\x0eOrderDirection\x12\x1f\n\x1bORDER_DIRECTION_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDER_DIRECTION_ASC\x10\x01\x12\x18\n\x14ORDER_DIRECTION_DESC\x10\x02\"\x86\x01\n\x14ListSessionsResponse\x12>\n\x08sessions\x18\x01 \x03(\x0b\x32,.armonik.api.grpc.v1.sessions.SessionSummary\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"\'\n\x11GetSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"O\n\x12GetSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"*\n\x14\x43\x61ncelSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"R\n\x15\x43\x61ncelSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRawB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _SESSIONRAW._serialized_start=126
  _SESSIONRAW._serialized_end=397
  _SESSIONSUMMARY._serialized_start=400
  _SESSIONSUMMARY._serialized_end=601
  _LISTSESSIONSREQUEST._serialized_start=604
  _LISTSESSIONSREQUEST._serialized_end=1611
  _LISTSESSIONSREQUEST_FILTER._serialized_start=805
  _LISTSESSIONSREQUEST_FILTER._serialized_end=1165
  _LISTSESSIONSREQUEST_SORT._serialized_start=1168
  _LISTSESSIONSREQUEST_SORT._serialized_end=1338
  _LISTSESSIONSREQUEST_ORDERBYFIELD._serialized_start=1341
  _LISTSESSIONSREQUEST_ORDERBYFIELD._serialized_end=1509
  _LISTSESSIONSREQUEST_ORDERDIRECTION._serialized_start=1511
  _LISTSESSIONSREQUEST_ORDERDIRECTION._serialized_end=1611
  _LISTSESSIONSRESPONSE._serialized_start=1614
  _LISTSESSIONSRESPONSE._serialized_end=1748
  _GETSESSIONREQUEST._serialized_start=1750
  _GETSESSIONREQUEST._serialized_end=1789
  _GETSESSIONRESPONSE._serialized_start=1791
  _GETSESSIONRESPONSE._serialized_end=1870
  _CANCELSESSIONREQUEST._serialized_start=1872
  _CANCELSESSIONREQUEST._serialized_end=1914
  _CANCELSESSIONRESPONSE._serialized_start=1916
  _CANCELSESSIONRESPONSE._serialized_end=1998
# @@protoc_insertion_point(module_scope)
